@@ -65,12 +65,12 @@ DEFAULT_MAX_PEERS = 30
 class Community(EZPackOverlay):
 
     version = b'\x02'
-    master_peer = ""
+    community_id = b''
 
     def __init__(self, my_peer, endpoint, network, max_peers=DEFAULT_MAX_PEERS, anonymize=False):
-        super(Community, self).__init__(self.master_peer, my_peer, endpoint, network)
+        super().__init__(self.community_id, my_peer, endpoint, network)
 
-        self._prefix = b'\x00' + self.version + self.master_peer.mid
+        self._prefix = b'\x00' + self.version + self.community_id
         self.endpoint.remove_listener(self)
         self.endpoint.add_prefix_listener(self, self._prefix)
         self.logger.debug("Launching %s with prefix %s.", self.__class__.__name__, hexlify(self._prefix))
@@ -84,7 +84,7 @@ class Community(EZPackOverlay):
             else:
                 self.logger.warning('Cannot anonymize community traffic without TunnelEndpoint')
 
-        self.network.register_service_provider(self.master_peer.mid, self)
+        self.network.register_service_provider(self.community_id, self)
         self.network.blacklist_mids.append(my_peer.mid)
         self.network.blacklist.extend(_DEFAULT_ADDRESSES)
 
@@ -187,9 +187,9 @@ class Community(EZPackOverlay):
                                              True,
                                              u"unknown",
                                              global_time,
-                                             extra_bytes).to_pack_list()
-        auth = BinMemberAuthenticationPayload(self.my_peer.public_key.key_to_bin()).to_pack_list()
-        dist = GlobalTimeDistributionPayload(global_time).to_pack_list()
+                                             extra_bytes)
+        auth = BinMemberAuthenticationPayload(self.my_peer.public_key.key_to_bin())
+        dist = GlobalTimeDistributionPayload(global_time)
 
         return self._ez_pack(self._prefix, 246, [auth, dist, payload])
 
@@ -217,9 +217,9 @@ class Community(EZPackOverlay):
                                               u"unknown",
                                               False,
                                               identifier,
-                                              extra_bytes).to_pack_list()
-        auth = BinMemberAuthenticationPayload(self.my_peer.public_key.key_to_bin()).to_pack_list()
-        dist = GlobalTimeDistributionPayload(global_time).to_pack_list()
+                                              extra_bytes)
+        auth = BinMemberAuthenticationPayload(self.my_peer.public_key.key_to_bin())
+        dist = GlobalTimeDistributionPayload(global_time)
 
         if introduced:
             packet = self.create_puncture_request(lan_socket_address, socket_address, identifier, prefix=prefix)
@@ -229,16 +229,16 @@ class Community(EZPackOverlay):
 
     def create_puncture(self, lan_walker, wan_walker, identifier):
         global_time = self.claim_global_time()
-        payload = PuncturePayload(lan_walker, wan_walker, identifier).to_pack_list()
-        auth = BinMemberAuthenticationPayload(self.my_peer.public_key.key_to_bin()).to_pack_list()
-        dist = GlobalTimeDistributionPayload(global_time).to_pack_list()
+        payload = PuncturePayload(lan_walker, wan_walker, identifier)
+        auth = BinMemberAuthenticationPayload(self.my_peer.public_key.key_to_bin())
+        dist = GlobalTimeDistributionPayload(global_time)
 
         return self._ez_pack(self._prefix, 249, [auth, dist, payload])
 
     def create_puncture_request(self, lan_walker, wan_walker, identifier, prefix=None):
         global_time = self.claim_global_time()
-        payload = PunctureRequestPayload(lan_walker, wan_walker, identifier).to_pack_list()
-        dist = GlobalTimeDistributionPayload(global_time).to_pack_list()
+        payload = PunctureRequestPayload(lan_walker, wan_walker, identifier)
+        dist = GlobalTimeDistributionPayload(global_time)
 
         return self._ez_pack(prefix or self._prefix, 250, [dist, payload], False)
 
@@ -274,7 +274,7 @@ class Community(EZPackOverlay):
             return
 
         self.network.add_verified_peer(peer)
-        self.network.discover_services(peer, [self.master_peer.mid, ])
+        self.network.discover_services(peer, [self.community_id, ])
 
         packet = self.create_introduction_response(payload.destination_address, peer.address, payload.identifier)
         self.endpoint.send(peer.address, packet)
@@ -287,20 +287,20 @@ class Community(EZPackOverlay):
             self.my_estimated_wan = payload.destination_address
 
         self.network.add_verified_peer(peer)
-        self.network.discover_services(peer, [self.master_peer.mid, ])
+        self.network.discover_services(peer, [self.community_id, ])
 
         if (payload.wan_introduction_address != ("0.0.0.0", 0)
                 and payload.wan_introduction_address[0] != self.my_estimated_wan[0]):
             if payload.lan_introduction_address != ("0.0.0.0", 0):
-                self.network.discover_address(peer, payload.lan_introduction_address, self.master_peer.mid)
-            self.network.discover_address(peer, payload.wan_introduction_address, self.master_peer.mid)
+                self.network.discover_address(peer, payload.lan_introduction_address, self.community_id)
+            self.network.discover_address(peer, payload.wan_introduction_address, self.community_id)
         elif (payload.lan_introduction_address != ("0.0.0.0", 0)
               and payload.wan_introduction_address[0] == self.my_estimated_wan[0]):
-            self.network.discover_address(peer, payload.lan_introduction_address, self.master_peer.mid)
+            self.network.discover_address(peer, payload.lan_introduction_address, self.community_id)
         elif payload.wan_introduction_address != ("0.0.0.0", 0):
-            self.network.discover_address(peer, payload.wan_introduction_address, self.master_peer.mid)
+            self.network.discover_address(peer, payload.wan_introduction_address, self.community_id)
             self.network.discover_address(peer, (self.my_estimated_lan[0], payload.wan_introduction_address[1]),
-                                          self.master_peer.mid)
+                                          self.community_id)
 
         self.introduction_response_callback(peer, dist, payload)
 
@@ -335,7 +335,7 @@ class Community(EZPackOverlay):
                 self.logger.error("Exception occurred while handling packet!\n"
                                   + ''.join(format_exception(*sys.exc_info())))
         elif warn_unknown:
-            self.logger.warning("Received unknown message: %d from (%s, %d)", ord(msg_id), *source_address)
+            self.logger.warning("Received unknown message: %d from (%s, %d)", msg_id, *source_address)
 
     def walk_to(self, address):
         packet = self.create_introduction_request(address)
@@ -375,7 +375,7 @@ class Community(EZPackOverlay):
         return choice(available) if available else None
 
     def get_walkable_addresses(self):
-        return self.network.get_walkable_addresses(self.master_peer.mid)
+        return self.network.get_walkable_addresses(self.community_id)
 
     def get_peers(self):
-        return self.network.get_peers_for_service(self.master_peer.mid)
+        return self.network.get_peers_for_service(self.community_id)
