@@ -1,4 +1,5 @@
 import logging
+import time
 from asyncio import Future
 
 from .tunnel import CIRCUIT_STATE_CLOSING, CIRCUIT_STATE_READY
@@ -10,7 +11,7 @@ class CreateRequestCache(NumberCache):
     Used to track outstanding create messages
     """
     def __init__(self, community, to_circuit_id, from_circuit_id, peer, to_peer):
-        super(CreateRequestCache, self).__init__(community.request_cache, u"create", to_circuit_id)
+        super(CreateRequestCache, self).__init__(community.request_cache, "create", to_circuit_id)
         self.community = community
         self.to_circuit_id = to_circuit_id
         self.from_circuit_id = from_circuit_id
@@ -28,7 +29,7 @@ class CreatedRequestCache(NumberCache):
     Used to track outstanding created messages
     """
     def __init__(self, community, circuit_id, candidate, candidates, timeout):
-        super(CreatedRequestCache, self).__init__(community.request_cache, u"created", circuit_id)
+        super(CreatedRequestCache, self).__init__(community.request_cache, "created", circuit_id)
         self.circuit_id = circuit_id
         self.candidate = candidate
         self.candidates = candidates
@@ -47,7 +48,7 @@ class RetryRequestCache(NumberCache):
     Used to track adding additional hops to the circuit.
     """
     def __init__(self, community, circuit, candidates, max_tries, retry_func, timeout):
-        super(RetryRequestCache, self).__init__(community.request_cache, u"retry", circuit.circuit_id)
+        super(RetryRequestCache, self).__init__(community.request_cache, "retry", circuit.circuit_id)
         self.community = community
         self.circuit = circuit
         self.candidates = candidates
@@ -79,7 +80,7 @@ class RetryRequestCache(NumberCache):
 class PingRequestCache(RandomNumberCache):
 
     def __init__(self, community, circuit):
-        super(PingRequestCache, self).__init__(community.request_cache, u"ping")
+        super(PingRequestCache, self).__init__(community.request_cache, "ping")
 
     def on_timeout(self):
         pass
@@ -88,7 +89,7 @@ class PingRequestCache(RandomNumberCache):
 class IPRequestCache(RandomNumberCache):
 
     def __init__(self, community, circuit):
-        super(IPRequestCache, self).__init__(community.request_cache, u"establish-intro")
+        super(IPRequestCache, self).__init__(community.request_cache, "establish-intro")
         self.logger = logging.getLogger(__name__)
         self.circuit = circuit
         self.community = community
@@ -101,7 +102,7 @@ class IPRequestCache(RandomNumberCache):
 class RPRequestCache(RandomNumberCache):
 
     def __init__(self, community, rp):
-        super(RPRequestCache, self).__init__(community.request_cache, u"establish-rendezvous")
+        super(RPRequestCache, self).__init__(community.request_cache, "establish-rendezvous")
         self.logger = logging.getLogger(__name__)
         self.community = community
         self.rp = rp
@@ -116,7 +117,7 @@ class RPRequestCache(RandomNumberCache):
 class PeersRequestCache(RandomNumberCache):
 
     def __init__(self, community, circuit, info_hash):
-        super(PeersRequestCache, self).__init__(community.request_cache, u"peers-request")
+        super(PeersRequestCache, self).__init__(community.request_cache, "peers-request")
         self.circuit = circuit
         self.info_hash = info_hash
         self.future = Future()
@@ -128,7 +129,7 @@ class PeersRequestCache(RandomNumberCache):
 class E2ERequestCache(RandomNumberCache):
 
     def __init__(self, community, info_hash, hop, intro_point):
-        super(E2ERequestCache, self).__init__(community.request_cache, u"e2e-request")
+        super(E2ERequestCache, self).__init__(community.request_cache, "e2e-request")
         self.community = community
         self.info_hash = info_hash
         self.hop = hop
@@ -144,10 +145,23 @@ class E2ERequestCache(RandomNumberCache):
 class LinkRequestCache(RandomNumberCache):
 
     def __init__(self, community, circuit, info_hash, hs_session_keys):
-        super(LinkRequestCache, self).__init__(community.request_cache, u"link-request")
+        super(LinkRequestCache, self).__init__(community.request_cache, "link-request")
         self.circuit = circuit
         self.info_hash = info_hash
         self.hs_session_keys = hs_session_keys
 
     def on_timeout(self):
         pass
+
+
+class TestRequestCache(RandomNumberCache):
+
+    def __init__(self, community, circuit):
+        super(TestRequestCache, self).__init__(community.request_cache, "test-request")
+        self.circuit = circuit
+        self.ts = time.time()
+        self.future = Future()
+        self.register_future(self.future)
+
+    def on_timeout(self):
+        pass
