@@ -91,8 +91,7 @@ class TunnelSettings(object):
 class TunnelCommunity(Community):
 
     version = b'\x02'
-    master_peer = Peer(unhexlify("4c69624e61434c504b3adbd575f1902f1d39debeb3d7b576dff1652ab6cede21c14545d134219b57b"
-                                 "413a597c87c2e37b8c9f99938e0d4db3cd4a79d6b53fb5bc0cb7d222d5c6eabfaa9"))
+    community_id = unhexlify('81ded07332bdc775aa5a46f96de9f8f390bbc9f3')
 
     def __init__(self, *args, **kwargs):
         self.settings = kwargs.pop('settings', TunnelSettings())
@@ -435,7 +434,7 @@ class TunnelCommunity(Community):
         if isinstance(payload, (DataPayload, TestRequestPayload, TestResponsePayload)):
             message = payload.to_bin()
         else:
-            message = self.serializer.pack_multiple(payload.to_pack_list()[1:])[0]
+            message = self.serializer.pack_serializable(payload)[4:]
         cell = CellPayload(circuit_id, pack('!B', payload.msg_id) + message, payload.msg_id in NO_CRYPTO_PACKETS)
         try:
             cell.encrypt(self.crypto, self.circuits.get(circuit_id), self.relay_session_keys.get(circuit_id))
@@ -458,8 +457,8 @@ class TunnelCommunity(Community):
         return len(packet)
 
     def send_destroy(self, peer, circuit_id, reason):
-        auth = BinMemberAuthenticationPayload(self.my_peer.public_key.key_to_bin()).to_pack_list()
-        payload = DestroyPayload(circuit_id, reason).to_pack_list()
+        auth = BinMemberAuthenticationPayload(self.my_peer.public_key.key_to_bin())
+        payload = DestroyPayload(circuit_id, reason)
         packet = self._ez_pack(self._prefix, 10, [auth, payload])
         self.send_packet(peer, packet)
 
@@ -570,7 +569,7 @@ class TunnelCommunity(Community):
         if not extra_bytes:
             return []
 
-        payload = self.serializer.unpack_to_serializables([ExtraIntroductionPayload], extra_bytes)[0]
+        payload, _ = self.serializer.unpack_serializable(ExtraIntroductionPayload, extra_bytes)
         return payload.flags
 
     def introduction_request_callback(self, peer, dist, payload):
@@ -581,13 +580,13 @@ class TunnelCommunity(Community):
 
     def create_introduction_request(self, socket_address, extra_bytes=b''):
         extra_payload = ExtraIntroductionPayload(self.settings.peer_flags)
-        extra_bytes = self.serializer.pack_multiple(extra_payload.to_pack_list())[0]
+        extra_bytes = self.serializer.pack_serializable(extra_payload)
         return super(TunnelCommunity, self).create_introduction_request(socket_address, extra_bytes)
 
     def create_introduction_response(self, lan_socket_address, socket_address, identifier,
                                      introduction=None, extra_bytes=b''):
         extra_payload = ExtraIntroductionPayload(self.settings.peer_flags)
-        extra_bytes = self.serializer.pack_multiple(extra_payload.to_pack_list())[0]
+        extra_bytes = self.serializer.pack_serializable(extra_payload)
         return super(TunnelCommunity, self).create_introduction_response(lan_socket_address, socket_address,
                                                                          identifier, introduction, extra_bytes)
 
