@@ -13,7 +13,6 @@ from ..messaging.payload_headers import BinMemberAuthenticationPayload, GlobalTi
 from ..messaging.serialization import PackError
 from ..peer import Peer
 from ..requestcache import NumberCache, RequestCache
-from ..util import cast_to_bin
 
 
 class PeriodicSimilarity(DiscoveryStrategy):
@@ -52,12 +51,7 @@ class PingRequestCache(NumberCache):
 class DiscoveryCommunity(Community):
 
     version = b'\x02'
-    master_peer = Peer(unhexlify("3081a7301006072a8648ce3d020106052b81040027038192000403b3ab059ced"
-                                 "9b20646ab5e01762b3595c5e8855227ae1e424cff38a1e4edee73734ff2e2e82"
-                                 "9eb4f39bab20d7578284fcba7251acd74e7daf96f21d01ea17077faf4d27a655"
-                                 "837d072baeb671287a88554e1191d8904b0dc572d09ff95f10ff092c8a5e2a01"
-                                 "cd500624376aec875a6e3028aab784cfaf0bac6527245db8d93900d904ac2a92"
-                                 "2a02716ccef5a22f7968"))
+    community_id = unhexlify('7e313685c1912a141279f8248fc8db5899c5df5a')
 
     def __init__(self, my_peer, endpoint, network, max_peers=DEFAULT_MAX_PEERS, anonymize=False):
         super(DiscoveryCommunity, self).__init__(my_peer, endpoint, network, max_peers=max_peers, anonymize=anonymize)
@@ -89,7 +83,7 @@ class DiscoveryCommunity(Community):
 
         peer = Peer(auth.public_key_bin, source_address)
         self.network.add_verified_peer(peer)
-        self.network.discover_services(peer, [self.master_peer.mid, ])
+        self.network.discover_services(peer, [self.community_id, ])
 
         introduce_to = getattr(payload, 'introduce_to', None)
         introduction = None
@@ -146,10 +140,9 @@ class DiscoveryCommunity(Community):
         return [service_id for service_id, overlay in self.network.service_overlays.items()
                 if overlay.my_peer == peer]
 
-    def custom_pack(self, peer, msg_num, format_list_list):
-        packet = self._prefix + cast_to_bin(chr(msg_num))
-        for format_list in format_list_list:
-            packet += self.serializer.pack_multiple(format_list)[0]
+    def custom_pack(self, peer, msg_num, payloads):
+        packet = self._prefix + bytes([msg_num])
+        packet += self.serializer.pack_serializable_list(payloads)
         packet += default_eccrypto.create_signature(peer.key, packet)
         return packet
 
@@ -159,24 +152,24 @@ class DiscoveryCommunity(Community):
                                            self.my_estimated_lan,
                                            self.my_estimated_wan,
                                            u"unknown",
-                                           self.get_my_overlays(peer)).to_pack_list()
-        auth = BinMemberAuthenticationPayload(peer.public_key.key_to_bin()).to_pack_list()
-        dist = GlobalTimeDistributionPayload(global_time).to_pack_list()
+                                           self.get_my_overlays(peer))
+        auth = BinMemberAuthenticationPayload(peer.public_key.key_to_bin())
+        dist = GlobalTimeDistributionPayload(global_time)
 
         return self.custom_pack(peer, 1, [auth, dist, payload])
 
     def create_similarity_response(self, identifier, peer):
         global_time = self.claim_global_time()
-        payload = SimilarityResponsePayload(identifier, self.get_my_overlays(peer), []).to_pack_list()
-        auth = BinMemberAuthenticationPayload(peer.public_key.key_to_bin()).to_pack_list()
-        dist = GlobalTimeDistributionPayload(global_time).to_pack_list()
+        payload = SimilarityResponsePayload(identifier, self.get_my_overlays(peer), [])
+        auth = BinMemberAuthenticationPayload(peer.public_key.key_to_bin())
+        dist = GlobalTimeDistributionPayload(global_time)
 
         return self.custom_pack(peer, 2, [auth, dist, payload])
 
     def send_ping(self, peer):
         global_time = self.claim_global_time()
-        payload = PingPayload(global_time).to_pack_list()
-        dist = GlobalTimeDistributionPayload(global_time).to_pack_list()
+        payload = PingPayload(global_time)
+        dist = GlobalTimeDistributionPayload(global_time)
 
         packet = self._ez_pack(self._prefix, 3, [dist, payload], False)
         self.request_cache.add(PingRequestCache(self.request_cache, global_time, peer, time()))
@@ -184,6 +177,6 @@ class DiscoveryCommunity(Community):
 
     def create_pong(self, identifier):
         global_time = self.claim_global_time()
-        payload = PongPayload(identifier).to_pack_list()
-        dist = GlobalTimeDistributionPayload(global_time).to_pack_list()
+        payload = PongPayload(identifier)
+        dist = GlobalTimeDistributionPayload(global_time)
         return self._ez_pack(self._prefix, 4, [dist, payload], False)
