@@ -22,8 +22,7 @@ class B(VariablePayload):
     A VariablePayload with a nested Payload.
     """
     format_list = [A]
-    optional_format_list = ['Q']
-    names = ["a", "o"]
+    names = ["a"]
 
 
 @vp_compile
@@ -112,9 +111,8 @@ class TestVariablePayload(TestBase):
         :type instance: Payload
         :return: the repacked instance
         """
-        plist = instance.to_pack_list()
-        serialized, _ = default_serializer.pack_multiple(plist)
-        deserialized, _ = default_serializer.unpack_to_serializables([payload], serialized)  # pylint: disable=E0632
+        serialized = default_serializer.pack_serializable(instance)
+        deserialized, _ = default_serializer.unpack_serializable(payload, serialized)  # pylint: disable=E0632
         return deserialized
 
     def test_base_unnamed(self):
@@ -287,7 +285,7 @@ class TestVariablePayload(TestBase):
         """
         d = D(0)
 
-        serialized, _ = default_serializer.pack_multiple(d.to_pack_list())
+        serialized = default_serializer.pack_serializable(d)
         deserialized = self._pack_and_unpack(D, d)
 
         self.assertEqual(d.a, 0)
@@ -300,7 +298,7 @@ class TestVariablePayload(TestBase):
         """
         d = CompiledD(0)
 
-        serialized, _ = default_serializer.pack_multiple(d.to_pack_list())
+        serialized = default_serializer.pack_serializable(d)
         deserialized = self._pack_and_unpack(CompiledD, d)
 
         self.assertEqual(d.a, 0)
